@@ -29,11 +29,12 @@
 typedef struct _PopplerAttachmentPrivate PopplerAttachmentPrivate;
 struct _PopplerAttachmentPrivate
 {
-  Object obj_stream;
+  Object *obj_stream;
 };
 
 #define POPPLER_ATTACHMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), POPPLER_TYPE_ATTACHMENT, PopplerAttachmentPrivate))
 
+static void poppler_attachment_dispose (GObject *obj);
 static void poppler_attachment_finalize (GObject *obj);
 
 G_DEFINE_TYPE (PopplerAttachment, poppler_attachment, G_TYPE_OBJECT)
@@ -46,10 +47,28 @@ poppler_attachment_init (PopplerAttachment *attachment)
 static void
 poppler_attachment_class_init (PopplerAttachmentClass *klass)
 {
+  G_OBJECT_CLASS (klass)->dispose = poppler_attachment_dispose;
   G_OBJECT_CLASS (klass)->finalize = poppler_attachment_finalize;
   g_type_class_add_private (klass, sizeof (PopplerAttachmentPrivate));
 }
 
+static void
+poppler_attachment_dispose (GObject *obj)
+{
+  PopplerAttachmentPrivate *priv;
+
+  priv = POPPLER_ATTACHMENT_GET_PRIVATE (obj);
+
+  if (priv->obj_stream)
+    {
+      priv->obj_stream->free();
+      delete priv->obj_stream;
+      priv->obj_stream = NULL;
+    }
+
+  G_OBJECT_CLASS (poppler_attachment_parent_class)->dispose (obj);
+}
+
 static void
 poppler_attachment_finalize (GObject *obj)
 {
@@ -69,24 +88,22 @@ poppler_attachment_finalize (GObject *obj)
     g_string_free (attachment->checksum, TRUE);
   attachment->checksum = NULL;
   
-  POPPLER_ATTACHMENT_GET_PRIVATE (attachment)->obj_stream.free();
-
   G_OBJECT_CLASS (poppler_attachment_parent_class)->finalize (obj);
 }
 
 /* Public functions */
 
 PopplerAttachment *
-_poppler_attachment_new (PopplerDocument *document,
-			 EmbFile         *emb_file)
+_poppler_attachment_new (EmbFile *emb_file)
 {
   PopplerAttachment *attachment;
+  PopplerAttachmentPrivate *priv;
 
-  g_assert (document != NULL);
   g_assert (emb_file != NULL);
 
   attachment = (PopplerAttachment *) g_object_new (POPPLER_TYPE_ATTACHMENT, NULL);
-  
+  priv = POPPLER_ATTACHMENT_GET_PRIVATE (attachment);
+
   if (emb_file->name ())
     attachment->name = _poppler_goo_string_to_utf8 (emb_file->name ());
   if (emb_file->description ())
@@ -94,13 +111,15 @@ _poppler_attachment_new (PopplerDocument *document,
 
   attachment->size = emb_file->size ();
   
-  _poppler_convert_pdf_date_to_gtime (emb_file->createDate (), &attachment->ctime);
-  _poppler_convert_pdf_date_to_gtime (emb_file->modDate (), &attachment->mtime);
+  _poppler_convert_pdf_date_to_gtime (emb_file->createDate (), (time_t *)&attachment->ctime);
+  _poppler_convert_pdf_date_to_gtime (emb_file->modDate (), (time_t *)&attachment->mtime);
 
-  attachment->checksum = g_string_new_len (emb_file->checksum ()->getCString (),
-					   emb_file->checksum ()->getLength ());
+  if (emb_file->checksum ()->getLength () > 0)
+	  attachment->checksum = g_string_new_len (emb_file->checksum ()->getCString (),
+						   emb_file->checksum ()->getLength ());
   
-  emb_file->streamObject().copy(&POPPLER_ATTACHMENT_GET_PRIVATE (attachment)->obj_stream);
+  priv->obj_stream = new Object();
+  emb_file->streamObject().copy(priv->obj_stream);
 
   return attachment;
 }
@@ -187,7 +206,7 @@ poppler_attachment_save (PopplerAttachment  *attachment,
 
 /**
  * poppler_attachment_save_to_callback:
- * @attachment: A #GdkPixbuf.
+ * @attachment: A #PopplerAttachment.
  * @save_func: a function that is called to save each block of data that the save routine generates.
  * @user_data: user data to pass to the save function.
  * @error: return location for error, or %NULL.
@@ -213,7 +232,7 @@ poppler_attachment_save_to_callback (PopplerAttachment          *attachment,
 
   g_return_val_if_fail (POPPLER_IS_ATTACHMENT (attachment), FALSE);
 
-  stream = POPPLER_ATTACHMENT_GET_PRIVATE (attachment)->obj_stream.getStream();
+  stream = POPPLER_ATTACHMENT_GET_PRIVATE (attachment)->obj_stream->getStream();
   stream->reset();
 
   do
