@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2005 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2005 Jeff Muizelaar <jeff@infidigm.net>
-// Copyright (C) 2005-2008 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005-2010 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006-2008 Pino Toscano <pino@kde.org>
 // Copyright (C) 2006 Nickolay V. Shmyrev <nshmyrev@yandex.ru>
 // Copyright (C) 2006 Scott Turner <scotty1024@mac.com>
@@ -91,6 +91,7 @@ void PDFRectangle::clipTo(PDFRectangle *rect) {
 PageAttrs::PageAttrs(PageAttrs *attrs, Dict *dict) {
   Object obj1;
   PDFRectangle mBox;
+  const GBool isPage = dict->is("Page");
 
   // get old/default values
   if (attrs) {
@@ -124,8 +125,8 @@ PageAttrs::PageAttrs(PageAttrs *attrs, Dict *dict) {
   if (!haveCropBox) {
     cropBox = mediaBox;
   }
-  else
-  {
+
+  if (isPage) {
     // cropBox can not be bigger than mediaBox
     if (cropBox.x2 - cropBox.x1 > mediaBox.x2 - mediaBox.x1)
     {
@@ -147,11 +148,13 @@ PageAttrs::PageAttrs(PageAttrs *attrs, Dict *dict) {
   artBox = cropBox;
   readBox(dict, "ArtBox", &artBox);
 
-  // clip all other boxes to the media box
-  cropBox.clipTo(&mediaBox);
-  bleedBox.clipTo(&mediaBox);
-  trimBox.clipTo(&mediaBox);
-  artBox.clipTo(&mediaBox);
+  if (isPage) {
+    // clip all other boxes to the media box
+    cropBox.clipTo(&mediaBox);
+    bleedBox.clipTo(&mediaBox);
+    trimBox.clipTo(&mediaBox);
+    artBox.clipTo(&mediaBox);
+  }
 
   // rotate
   dict->lookup("Rotate", &obj1);
@@ -269,7 +272,7 @@ Page::Page(XRef *xrefA, int numA, Dict *pageDict, Ref pageRefA, PageAttrs *attrs
 
   // transtion
   pageDict->lookupNF("Trans", &trans);
-  if (!(trans.isDict() || trans.isNull())) {
+  if (!(trans.isRef() || trans.isDict() || trans.isNull())) {
     error(-1, "Page transition object (page %d) is wrong type (%s)",
 	  num, trans.getTypeName());
     trans.free();
@@ -554,7 +557,7 @@ GBool Page::loadThumb(unsigned char **data_out,
     obj1.free ();
     dict->lookup ("CS", &obj1);
   }
-  colorSpace = GfxColorSpace::parse(&obj1);
+  colorSpace = GfxColorSpace::parse(&obj1, NULL);
   obj1.free();
   if (!colorSpace) {
     fprintf (stderr, "Error: Cannot parse color space\n");
