@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2005 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2006 Stefan Schweizer <genstef@gentoo.org>
-// Copyright (C) 2006-2009 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006-2010 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006 Krzysztof Kowalczyk <kkowalczyk@gmail.com>
 // Copyright (C) 2006 Scott Turner <scotty1024@mac.com>
 // Copyright (C) 2007 Koji Otani <sho@bbr.jp>
@@ -1812,6 +1812,21 @@ void SplashOutputDev::type3D1(GfxState *state, double wx, double wy,
   double xt, yt, xMin, xMax, yMin, yMax, x1, y1;
   int i, j;
 
+  if (unlikely(t3GlyphStack == NULL)) {
+    error(-1, "t3GlyphStack was null in SplashOutputDev::type3D1");
+    return;
+  }
+
+  if (unlikely(t3GlyphStack->origBitmap != NULL)) {
+    error(-1, "t3GlyphStack origBitmap was not null in SplashOutputDev::type3D1");
+    return;
+  }
+
+  if (unlikely(t3GlyphStack->origSplash != NULL)) {
+    error(-1, "t3GlyphStack origSplash was not null in SplashOutputDev::type3D1");
+    return;
+  }
+
   t3Font = t3GlyphStack->cache;
 
   // check for a valid bbox
